import React from "react";
import { styled } from "@mui/material/styles";
import { Button, Grid } from "@mui/material";
import Alert from "@mui/material/Alert";

const PREFIX = "AlertMessages";

const classes = {
  infoBadge: `${PREFIX}-infoBadge`
};

const StyledGrid = styled(Grid)(({ theme }) => ({
  [`& .${classes.infoBadge}`]: {
    backgroundColor: theme.infoBadge.bgColor
  }
}));

export default function AlertMessages({ alerts }) {
  function determineSeverity(alarmType) {
    return ["error", "warning", "success"].includes(alarmType?.toLowerCase())
      ? alarmType?.toLowerCase()
      : "info";
  }

  function determineClassName(alarmType) {
    if (alarmType === "INFO") {
      return classes.infoBadge;
    }
  }

  return (
    <StyledGrid
      id="ioc-alerts"
      container
      spacing={1}
      direction="column"
    >
      {alerts?.map((alert) => (
        <Grid
          item
          key={alert?.message || alert}
        >
          <Alert
            className={determineClassName(alert?.type)}
            severity={determineSeverity(alert?.type)}
            action={
              alert?.link && (
                <Button
                  target="_blank"
                  href={alert.link}
                  color="inherit"
                  size="small"
                >
                  More Info
                </Button>
              )
            }
          >
            {alert?.message}
          </Alert>
        </Grid>
      ))}
    </StyledGrid>
  );
}
