import React from "react";
import { Card, CardHeader } from "@mui/material";
import { initRequestParams } from "../Helper";
import { useEffect } from "react";
import { useOperationsSearch } from "../../../api/SwaggerApi";
import { usePagination } from "../../../hooks/pagination";
import { JobTable } from "../../Job";

export function UserOperationList({ userName }) {
  const [operations, getOperations, , loading] = useOperationsSearch();

  const rowsPerPage = [20, 50];
  const { pagination, setPagination } = usePagination({
    rowsPerPageOptions: rowsPerPage,
    initLimit: rowsPerPage[0],
    initPage: 0
  });

  // update pagination whenever search result total pages change
  useEffect(() => {
    setPagination({ totalCount: operations.totalCount ?? 0 });
  }, [setPagination, operations.totalCount]);

  useEffect(() => {
    let requestParams = initRequestParams(pagination);

    requestParams.user = userName;

    getOperations(requestParams);
  }, [getOperations, pagination, userName]);

  // Invoked by Table on change to pagination
  const onPage = (params) => {
    setPagination(params);
  };

  return (
    <Card variant="plain">
      <CardHeader
        title={"Operations"}
        titleTypographyProps={{
          variant: "h2",
          component: "h2"
        }}
      />
      <JobTable
        jobs={operations.operationsList}
        loading={loading}
        pagination={pagination}
        onPage={onPage}
        rowType="userPageJobLog"
      />
    </Card>
  );
}
