import { createTheme } from "@mui/material/styles";
import { chartColors } from "./Palette";
import { theme as ceuiTheme } from "@ess-ics/ce-ui-common";

let theme = createTheme(ceuiTheme, {});

theme = createTheme(theme, {
  components: {
    MuiWithWidth: {
      defaultProps: {
        initialWidth: "lg"
      }
    },
    MuiTooltip: {
      tooltip: {
        fontSize: "0.875rem",
        backgroundColor: "#707070ff"
      }
    },
    MuiListItemButton: {
      styleOverrides: {
        root: {
          "&.Mui-selected, &.Mui-selected:hover": {
            backgroundColor: "#cccccc"
          },
          "&:hover": {
            backgroundColor: "#ddddddff"
          }
        }
      }
    },
    MuiInputBase: {
      styleOverrides: {
        root: {
          fontSize: "0.875rem",
          paddingY: 2
        }
      }
    },
    MuiTypography: {
      body1: {
        fontSize: "0.875rem"
      }
    },
    MuiDialogContent: {
      styleOverrides: {
        root: {
          paddingTop: "0.5rem !important",
          paddingBottom: "0.5rem !important"
        }
      }
    }
  },
  palette: {
    primary: {
      main: "#0099dc"
    },
    secondary: {
      main: "#0d598e"
    },
    status: {
      ok: "#4caf50",
      fail: "#aa2e25",
      neutral: "#000",
      progress: "#ffc107",
      icons: "#454545"
    },
    graph: chartColors
  },
  typography: {
    fontFamily: [
      "-apple-system",
      "BlinkMacSystemFont",
      '"Segoe UI"',
      "Roboto",
      '"Helvetica Neue"',
      "Arial",
      "Noto Sans",
      "sans-serif",
      '"Apple Color Emoji"',
      '"Segoe UI Emoji"',
      '"Segoe UI Symbol"',
      '"Noto Color Emoji"'
    ].join(","),
    h1: {
      fontFamily: "Titillium Web, sans-serif",
      [theme.breakpoints.down("md")]: {
        fontSize: "0.98rem"
      },
      [theme.breakpoints.up("md")]: {
        fontSize: "1.31rem"
      }
    },
    h2: {
      fontFamily: ["Segoe UI", "Roboto", "Noto Sans"].join(","),
      [theme.breakpoints.down("md")]: {
        fontSize: "1.3rem"
      },
      [theme.breakpoints.up("md")]: {
        fontSize: "1.7rem"
      },
      fontWeight: 600
    },
    h3: {
      fontFamily: ["Segoe UI", "Roboto", "Noto Sans"].join(","),
      [theme.breakpoints.down("md")]: {
        fontSize: "1.25rem"
      },
      [theme.breakpoints.up("md")]: {
        fontSize: "1.75rem"
      },
      fontWeight: 600
    },
    h4: {
      fontFamily: ["Segoe UI", "Roboto", "Noto Sans"].join(","),
      [theme.breakpoints.down("md")]: {
        fontSize: "0,98rem"
      },
      [theme.breakpoints.up("md")]: {
        fontSize: "1.09rem"
      },
      fontWeight: 600
    },
    h5: {
      fontFamily: ["Segoe UI", "Roboto", "Noto Sans"].join(","),
      [theme.breakpoints.down("md")]: {
        fontSize: "0.98rem"
      },
      [theme.breakpoints.up("md")]: {
        fontSize: "0.875rem"
      },
      fontWeight: 600
    },
    h6: {
      fontFamily: ["Segoe UI", "Roboto", "Noto Sans"].join(","),
      [theme.breakpoints.down("md")]: {
        fontSize: "0.765rem"
      },
      [theme.breakpoints.up("md")]: {
        fontSize: "0.875rem"
      },
      fontWeight: 600
    },
    overline: {
      fontFamily: ["Segoe UI", "Roboto", "Noto Sans"].join(","),
      [theme.breakpoints.down("md")]: {
        fontSize: "0.656rem"
      },
      [theme.breakpoints.up("md")]: {
        fontSize: "0.875rem"
      },
      fontWeight: 600
    },
    body1: {
      fontFamily: ["Segoe UI", "Roboto", "Noto Sans"].join(","),
      [theme.breakpoints.down("md")]: {
        fontSize: "0.765rem !important",
        fontWeight: 600
      },
      [theme.breakpoints.down("md")]: {
        fontSize: "0.875rem !important"
      }
    },
    button: {
      fontFamily: ["Segoe UI", "Roboto", "Noto Sans"].join(","),
      [theme.breakpoints.down("md")]: {
        fontSize: "0,656rem"
      },
      [theme.breakpoints.up("md")]: {
        fontSize: "0,765rem"
      },
      fontWeight: 500
    }
  },
  cccecustomtable: {
    fontSize: "0.765rem"
  },
  infoBadge: {
    bgColor: "#ececec"
  },
  iocNotDeployed: {
    color: "#b2b2b2"
  },
  csentryIdInvalid: {
    color: "#b2b2b2"
  }
});

export { theme };
